(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     67460,       2524]
NotebookOptionsPosition[     60803,       2281]
NotebookOutlinePosition[     61151,       2296]
CellTagsIndexPosition[     61108,       2293]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Von Neumann Stability Analysis", "Title"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"j_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"xi", "^", "n"}], " ", 
   RowBox[{"Exp", "[", 
    RowBox[{"h", " ", "I", " ", "j", " ", "k"}], "]"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell["FTCS", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq", "=", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"j", ",", 
     RowBox[{"n", "+", "1"}]}], "]"}], "-", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"j", "-", "1"}], ",", "n"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{"j", ",", "n"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"j", "+", "1"}], ",", "n"}], "]"}]}], "}"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"C", "/", "2"}], ",", "1", ",", 
      RowBox[{
       RowBox[{"-", "C"}], "/", "2"}]}], "}"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "C", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "j"}], ")"}], " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "-", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", "j", " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "C", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "j"}], ")"}], " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", "j", " ", "k"}]], " ", 
   SuperscriptBox["xi", 
    RowBox[{"1", "+", "n"}]]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"eq", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"xi", "^", "n"}], " ", 
      RowBox[{"Exp", "[", 
       RowBox[{"h", " ", "I", " ", "j", " ", "k"}], "]"}]}], ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "C", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", "k"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "h", " ", "k"}]]}], ")"}]}], 
  "+", "xi"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ampl", " ", "=", " ", 
  RowBox[{"xi", "/.", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"eq1", "\[Equal]", "0"}], ",", "xi"}], "]"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", "k"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "C"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "h", " ", "k"}]]}], "+", 
    RowBox[{"C", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "h", " ", "k"}]]}]}], 
   ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ComplexExpand", "[", "ampl", "]"}], "//", "Simplify"}]], "Input"],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"\[ImaginaryI]", " ", "C", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"h", " ", "k"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Abs", "[", "%", "]"}], "//", "ComplexExpand"}]], "Input"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"1", "+", 
   RowBox[{
    SuperscriptBox["C", "2"], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      RowBox[{"h", " ", "k"}], "]"}], "2"]}]}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lax", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq", "=", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"j", ",", 
     RowBox[{"n", "+", "1"}]}], "]"}], "-", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"j", "-", "1"}], ",", "n"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{"j", ",", "n"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"j", "+", "1"}], ",", "n"}], "]"}]}], "}"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "C"}], ")"}], "/", "2"}], ",", "0", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "C"}], ")"}], "/", "2"}]}], "}"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "C"}], ")"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "j"}], ")"}], " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "C"}], ")"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "j"}], ")"}], " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", "j", " ", "k"}]], " ", 
   SuperscriptBox["xi", 
    RowBox[{"1", "+", "n"}]]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"eq", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"xi", "^", "n"}], " ", 
      RowBox[{"Exp", "[", 
       RowBox[{"h", " ", "I", " ", "j", " ", "k"}], "]"}]}], ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", "k"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "h", " ", "k"}]], "+", 
    RowBox[{"C", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "h", " ", "k"}]]}], ")"}]}], 
    "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "h", " ", "k"}]], " ", "xi"}]}], 
   ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ampl", " ", "=", " ", 
  RowBox[{"xi", "/.", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"eq1", "\[Equal]", "0"}], ",", "xi"}], "]"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", "k"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "-", "C", "-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "h", " ", "k"}]], "+", 
    RowBox[{"C", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "h", " ", "k"}]]}]}], 
   ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ComplexExpand", "[", "ampl", "]"}], "//", "Simplify"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", 
   RowBox[{"h", " ", "k"}], "]"}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "C", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"h", " ", "k"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Abs", "[", "%", "]"}], "^", "2"}], "//", 
  "ComplexExpand"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"Cos", "[", 
    RowBox[{"h", " ", "k"}], "]"}], "2"], "+", 
  RowBox[{
   SuperscriptBox["C", "2"], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     RowBox[{"h", " ", "k"}], "]"}], "2"]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Upwind Explicit", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq", "=", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"j", ",", 
     RowBox[{"n", "+", "1"}]}], "]"}], "-", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"j", "-", "1"}], ",", "n"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{"j", ",", "n"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"j", "+", "1"}], ",", "n"}], "]"}]}], "}"}], ".", 
    RowBox[{"{", 
     RowBox[{"C", ",", 
      RowBox[{"1", "-", "C"}], ",", "0"}], "}"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "C"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "j"}], ")"}], " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "C"}], ")"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", "j", " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", "j", " ", "k"}]], " ", 
   SuperscriptBox["xi", 
    RowBox[{"1", "+", "n"}]]}]}]], "Output",
 CellChangeTimes->{{3.7360156810078335`*^9, 3.7360156985858607`*^9}, 
   3.7360179801619864`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"eq", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"xi", "^", "n"}], " ", 
      RowBox[{"Exp", "[", 
       RowBox[{"h", " ", "I", " ", "j", " ", "k"}], "]"}]}], ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", "C", "-", 
  RowBox[{"C", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", "k"}]]}], "+", 
  "xi"}]], "Output",
 CellChangeTimes->{3.7360157011796207`*^9, 3.736017982161974*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ampl", " ", "=", " ", 
  RowBox[{"xi", "/.", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"eq1", "\[Equal]", "0"}], ",", "xi"}], "]"}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"1", "-", "C", "+", 
  RowBox[{"C", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", "k"}]]}]}]], "Output",
 CellChangeTimes->{3.736015710554575*^9, 3.7360179838963404`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{"ampl", ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7360177577101*^9, 3.73601778403809*^9}, {
   3.7360178798656836`*^9, 3.736017884459401*^9}, 3.7360179552090187`*^9, 
   3.7360179978493853`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   RowBox[{"\[ImaginaryI]", " ", "C", " ", "h", " ", "k"}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"C", " ", 
      SuperscriptBox["h", "2"]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", "\[ImaginaryI]", " ", "C", " ", 
    SuperscriptBox["h", "3"], " ", 
    SuperscriptBox["k", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "k", "]"}], "4"],
    SeriesData[$CellContext`k, 0, {}, 0, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`k, 0, {
   1, (Complex[0, -1] C) $CellContext`h, (Rational[-1, 2] 
     C) $CellContext`h^2, (Complex[0, 
       Rational[1, 6]] C) $CellContext`h^3}, 0, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.736017776991249*^9, 3.73601778599119*^9}, 
   3.7360178863031335`*^9, 3.7360179560683837`*^9, {3.736017986552576*^9, 
   3.736017998521259*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Log", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.736017890599984*^9, 3.7360178988812037`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[ImaginaryI]", " ", "C", " ", "h", " ", "k"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "C"}], " ", 
       SuperscriptBox["h", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["C", "2"], " ", 
       SuperscriptBox["h", "2"]}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "C", " ", 
       SuperscriptBox["h", "3"]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["C", "2"], " ", 
       SuperscriptBox["h", "3"]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "C", " ", "h", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"C", " ", 
           SuperscriptBox["h", "2"]}], "2"], "-", 
         RowBox[{
          SuperscriptBox["C", "2"], " ", 
          SuperscriptBox["h", "2"]}]}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox["k", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "k", "]"}], "4"],
    SeriesData[$CellContext`k, 0, {}, 1, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`k, 
   0, {(Complex[0, -1] C) $CellContext`h, 
    Rational[1, 2] ((-C) $CellContext`h^2 + C^2 $CellContext`h^2), 
    Rational[1, 3] ((Complex[0, 
         Rational[1, 2]] C) $CellContext`h^3 + (Complex[0, -1] 
       C^2) $CellContext`h^3 + ((Complex[0, -1] 
        C) $CellContext`h) ((Rational[1, 2] C) $CellContext`h^2 - 
       C^2 $CellContext`h^2))}, 1, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.736017900849943*^9, 3.736017957271487*^9, {3.736017992661928*^9, 
   3.7360180010368805`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{"ComplexExpand", "[", "ampl", "]"}], "//", "Simplify"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"1", "-", "C", "+", 
  RowBox[{"C", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"h", " ", "k"}], "]"}]}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "C", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"h", " ", "k"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7360157183045197`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"D", "[", "tmp"}]], "Input",
 CellChangeTimes->{{3.736017745069543*^9, 3.736017747553932*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Abs", "[", "tmp", "]"}], "//", "ComplexExpand"}]], "Input"],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "C", "+", 
      RowBox[{"C", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"h", " ", "k"}], "]"}]}]}], ")"}], "2"], "+", 
   RowBox[{
    SuperscriptBox["C", "2"], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      RowBox[{"h", " ", "k"}], "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{3.7360165500882215`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "C", "+", 
         RowBox[{"C", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", "h2", " ", "k"}], "]"}]}]}], ")"}], "2"], "+", 
      RowBox[{
       SuperscriptBox["C", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"2", "h2", " ", "k"}], "]"}], "2"]}]}], ",", "C"}], "]"}], "//",
    "TrigExpand"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.736017297634537*^9, 3.7360173657591796`*^9}, {
  3.736017399993367*^9, 3.7360174040870914`*^9}, {3.7360174385243998`*^9, 
  3.736017465039878*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      RowBox[{"h2", " ", "k"}], "]"}], "2"]}], ",", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      RowBox[{"h2", " ", "k"}], "]"}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7360173062282324`*^9, 3.736017366540412*^9}, 
   3.736017405102682*^9, {3.736017445539957*^9, 3.7360174663835926`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "C", "+", 
         RowBox[{"C", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"h", " ", "k"}], "]"}]}]}], ")"}], "2"], "+", 
      RowBox[{
       SuperscriptBox["C", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"h", " ", "k"}], "]"}], "2"]}]}]], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", "2"}], "}"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7360163870578766`*^9, 3.7360164973541584`*^9}, 
   3.7360165588537917`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "C"}], ")"}], " ", "C", " ", 
    SuperscriptBox["h", "2"], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "k", "]"}], "3"],
    SeriesData[$CellContext`k, 0, {}, 0, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`k, 0, {
   1, 0, ((Rational[1, 2] (-1 + C)) C) $CellContext`h^2}, 0, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7360163959171953`*^9, 3.736016498057251*^9}, 
   3.7360165618693976`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"1", "-", "C", "+", 
      RowBox[{"C", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"h", " ", "k"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", "C"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"h", " ", "k"}], "]"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7360163026833553`*^9, 3.7360163571986876`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"C", " ", "h", " ", "k"}]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C", " ", 
       SuperscriptBox["h", "3"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["C", "2"], " ", 
       SuperscriptBox["h", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["C", "3"], " ", 
       SuperscriptBox["h", "3"]}]}], ")"}], " ", 
    SuperscriptBox["k", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "k", "]"}], "4"],
    SeriesData[$CellContext`k, 0, {}, 1, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`k, 
   0, {(-C) $CellContext`h, 0, 
    Rational[1, 6] (
     C $CellContext`h^3 - (3 
      C^2) $CellContext`h^3 + (2 C^3) $CellContext`h^3)}, 1, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.736016339214384*^9, 3.7360163582299027`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{"tmp", ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", "2"}], "}"}]}], "]"}], "//", 
  "Normal"}]], "Input",
 CellChangeTimes->{{3.736016262417946*^9, 3.7360162772616324`*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"\[ImaginaryI]", " ", "C", " ", "h", " ", "k"}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "C", " ", 
   SuperscriptBox["h", "2"], " ", 
   SuperscriptBox["k", "2"]}]}]], "Output",
 CellChangeTimes->{{3.7360162698554096`*^9, 3.7360162781053495`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Abs", "[", "tmp", "]"}], "//", "ComplexExpand"}]], "Input",
 CellChangeTimes->{{3.736016056378965*^9, 3.7360160654570484`*^9}}],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "C", "+", 
      RowBox[{"C", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"h", " ", "k"}], "]"}]}]}], ")"}], "2"], "+", 
   RowBox[{
    SuperscriptBox["C", "2"], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      RowBox[{"h", " ", "k"}], "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{3.7360160666601686`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Arg", "[", "tmp", "]"}], "//", "ComplexExpand"}]], "Input",
 CellChangeTimes->{{3.736016135753524*^9, 3.736016136456645*^9}}],

Cell[BoxData[
 RowBox[{"Arg", "[", 
  RowBox[{"1", "-", "C", "+", 
   RowBox[{"C", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"h", " ", "k"}], "]"}]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", "C", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"h", " ", "k"}], "]"}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.7360161376441565`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp1", "=", 
  RowBox[{
   RowBox[{"ComplexExpand", "[", 
    RowBox[{"tmp", " ", 
     RowBox[{"Conjugate", "[", "tmp", "]"}]}], "]"}], "//", 
   "Simplify"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"2", " ", "C"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["C", "2"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "C"}], ")"}], " ", "C", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"h", " ", "k"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.736015729929444*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"tmp1", ",", "C"}], "]"}]], "Input",
 CellChangeTimes->{{3.736015954254545*^9, 3.736015960816991*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SuperscriptBox["C", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"h", " ", "k"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{"C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"h", " ", "k"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.736015961832612*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lax-Wendroff", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq", "=", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"j", ",", 
     RowBox[{"n", "+", "1"}]}], "]"}], "-", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"j", "-", "1"}], ",", "n"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{"j", ",", "n"}], "]"}], ",", 
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"j", "+", "1"}], ",", "n"}], "]"}]}], "}"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"C", "/", "2"}], " ", "+", 
       RowBox[{
        RowBox[{"C", "^", "2"}], "/", "2"}]}], ",", 
      RowBox[{"1", "-", 
       RowBox[{"C", "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C"}], "/", "2"}], "+", 
       RowBox[{
        RowBox[{"C", "^", "2"}], "/", "2"}]}]}], "}"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["C", "2"], "+", 
      FractionBox[
       SuperscriptBox["C", "2"], "2"]}], ")"}]}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "j"}], ")"}], " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["C", "2"]}], ")"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", "j", " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["C", "2"]}], "+", 
     FractionBox[
      SuperscriptBox["C", "2"], "2"]}], ")"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "j"}], ")"}], " ", "k"}]], " ", 
   SuperscriptBox["xi", "n"]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", "h", " ", "j", " ", "k"}]], " ", 
   SuperscriptBox["xi", 
    RowBox[{"1", "+", "n"}]]}]}]], "Output",
 CellChangeTimes->{3.7360166563688717`*^9, 3.7360184412517576`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"eq", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"xi", "^", "n"}], " ", 
      RowBox[{"Exp", "[", 
       RowBox[{"h", " ", "I", " ", "j", " ", "k"}], "]"}]}], ")"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", "k"}]], " ", 
  RowBox[{"(", 
   RowBox[{"C", "-", 
    RowBox[{"C", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "h", " ", "k"}]]}], "+", 
    RowBox[{
     SuperscriptBox["C", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "h", " ", "k"}]]}], ")"}], "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "h", " ", "k"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "xi"}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.7360166591344805`*^9, 3.736018443361122*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ampl", " ", "=", " ", 
  RowBox[{
   RowBox[{"xi", "/.", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"eq1", "\[Equal]", "0"}], ",", "xi"}], "]"}], "]"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7360185623494177`*^9, 3.7360185653337812`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", "h", " ", "k"}]], " ", 
  RowBox[{"(", 
   RowBox[{"C", "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "h", " ", "k"}]]}], "-", 
    RowBox[{"C", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "h", " ", "k"}]]}], "+", 
    RowBox[{
     SuperscriptBox["C", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "h", " ", "k"}]]}], ")"}], "2"]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.7360166632037096`*^9, 3.7360184455642447`*^9, 
  3.736018566333783*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{"ComplexExpand", "[", "ampl", "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7360167337814465`*^9, 3.736016734453344*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox["C", "2"], "+", 
  RowBox[{
   SuperscriptBox["C", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"h", " ", "k"}], "]"}]}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "C", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"h", " ", "k"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.736016668203683*^9, 3.7360167354064384`*^9, 
  3.736018470224907*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp1", "=", 
  RowBox[{
   RowBox[{"Abs", "[", "tmp", "]"}], "//", "ComplexExpand"}]}]], "Input",
 CellChangeTimes->{{3.736016740593934*^9, 3.736016759625086*^9}}],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["C", "2"], "+", 
      RowBox[{
       SuperscriptBox["C", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"h", " ", "k"}], "]"}]}]}], ")"}], "2"], "+", 
   RowBox[{
    SuperscriptBox["C", "2"], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      RowBox[{"h", " ", "k"}], "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{
  3.73601667509427*^9, {3.7360167418907843`*^9, 3.736016760406295*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["C", "2"], "+", 
         RowBox[{
          SuperscriptBox["C", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"h", " ", "k"}], "]"}]}]}], ")"}], "2"], "+", 
      RowBox[{
       SuperscriptBox["C", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"h", " ", "k"}], "]"}], "2"]}]}], " ", ",", "C"}], "]"}], "//",
    "TrigExpand"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7360169310740957`*^9, 3.736016961527052*^9}, {
  3.736016998323722*^9, 3.7360170825419865`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"h", " ", "k"}], "2"], "]"}], "4"]}], ",", "0", ",", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"h", " ", "k"}], "2"], "]"}], "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7360169361521645`*^9, 3.736016962261395*^9}, {
  3.7360170053236556`*^9, 3.7360170834013453`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp2", "=", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"1", "-", 
     SuperscriptBox["C", "2"], "+", 
     RowBox[{
      SuperscriptBox["C", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"h", " ", "k"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"-", " ", "C"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"h", " ", "k"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7360171302292147`*^9, 3.7360171608384237`*^9}}],

Cell[BoxData[
 RowBox[{"ArcTan", "[", 
  RowBox[{
   RowBox[{"1", "-", 
    SuperscriptBox["C", "2"], "+", 
    RowBox[{
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"h", " ", "k"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "C"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"h", " ", "k"}], "]"}]}]}], "]"}]], "Output",
 CellChangeTimes->{{3.7360171537915907`*^9, 3.736017161885283*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{"tmp2", ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.73601716504152*^9, 3.7360171808227077`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"C", " ", "h", " ", "k"}]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"C", " ", 
       SuperscriptBox["h", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["C", "3"], " ", 
       SuperscriptBox["h", "3"]}]}], ")"}], " ", 
    SuperscriptBox["k", "3"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "k", "]"}], "4"],
    SeriesData[$CellContext`k, 0, {}, 1, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`k, 
   0, {(-C) $CellContext`h, 0, 
    Rational[1, 6] (C $CellContext`h^3 - C^3 $CellContext`h^3)}, 1, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7360171770727005`*^9, 3.7360171812758026`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Consistency", "Title"],

Cell[CellGroupData[{

Cell["Explicit Upwind", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"diffscheme", "=", 
  RowBox[{
   RowBox[{"Series", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", ",", 
           RowBox[{"t", "+", "dt"}]}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "/", "dt"}], " ", "+", 
      RowBox[{"v", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{
            RowBox[{"x", "+", "h"}], ",", "t"}], "]"}], "-", 
          RowBox[{"f", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "/", "h"}]}]}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"dt", ",", "0", ",", "2"}], "}"}]}], "]"}], "//", 
   "Normal"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["f", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "t"}], "]"}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "dt", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["dt", "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{"v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "h", " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["h", "2"], " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"truncerr", "=", 
  RowBox[{"diffscheme", " ", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}], "+", 
     RowBox[{"v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "dt", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["dt", "2"], " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "h", " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["h", "2"], " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"truncerr", "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "t"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"v", "^", "2"}], 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["dt", "2"], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"h", "+", 
          RowBox[{"dt", " ", "v"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["h", "2"], " ", 
        RowBox[{
         SuperscriptBox["f", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"3", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FTCS", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"diffscheme", "=", 
  RowBox[{
   RowBox[{"Series", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", ",", 
           RowBox[{"t", "+", "dt"}]}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "/", "dt"}], " ", "+", 
      RowBox[{"v", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{
            RowBox[{"x", "+", "h"}], ",", "t"}], "]"}], "-", 
          RowBox[{"f", "[", 
           RowBox[{
            RowBox[{"x", "-", "h"}], ",", "t"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "h"}], ")"}]}]}]}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"dt", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
   "Normal"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["f", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "t"}], "]"}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "dt", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{"v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["h", "2"], " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"truncerr", "=", 
  RowBox[{"diffscheme", " ", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}], "+", 
     RowBox[{"v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "dt", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["h", "2"], " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"truncerr", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"v", "^", "2"}], 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}]}], "/.", 
   RowBox[{"dt", "\[Rule]", 
    RowBox[{"h", " ", 
     RowBox[{"C", "/", "v"}]}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", "h", " ", "v", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", "C", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"h", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"3", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lax", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"diffscheme", "=", 
  RowBox[{
   RowBox[{"Series", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", ",", 
           RowBox[{"t", "+", "dt"}]}], "]"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"f", "[", 
             RowBox[{
              RowBox[{"x", "+", "h"}], ",", "t"}], "]"}], "+", 
            RowBox[{"f", "[", 
             RowBox[{
              RowBox[{"x", "-", "h"}], ",", "t"}], "]"}]}], ")"}], "/", 
          "2"}]}], ")"}], "/", "dt"}], " ", "+", 
      RowBox[{"v", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{
            RowBox[{"x", "+", "h"}], ",", "t"}], "]"}], "-", 
          RowBox[{"f", "[", 
           RowBox[{
            RowBox[{"x", "-", "h"}], ",", "t"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "h"}], ")"}]}]}]}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"dt", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
   "Normal"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["f", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "t"}], "]"}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "dt", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{"v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["h", "2"], " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "t"}], "]"}]}], 
   RowBox[{"2", " ", "dt"}]], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["h", "2"], " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"truncerr", "=", 
  RowBox[{"diffscheme", " ", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}], "+", 
     RowBox[{"v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "dt", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["h", "2"], " ", 
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "t"}], "]"}]}], 
   RowBox[{"2", " ", "dt"}]], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox["h", "2"], " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"truncerr", "/.", 
   RowBox[{"dt", "\[Rule]", 
    RowBox[{"h", " ", 
     RowBox[{"C", "/", "v"}]}]}]}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"h", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "C", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["v", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"2", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{"C", " ", "h", " ", 
          RowBox[{
           SuperscriptBox["f", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"3", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "C"]}], ")"}]}], 
  RowBox[{"6", " ", "v"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"truncerr", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"v", "^", "2"}], 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}]}], "/.", 
   RowBox[{"dt", "\[Rule]", 
    RowBox[{"h", " ", 
     RowBox[{"C", "/", "v"}]}]}]}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"h", " ", "v", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["C", "2"]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "+", 
     RowBox[{"C", " ", "h", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], 
  RowBox[{"6", " ", "C"}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Explicit Upwind", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"diffscheme", "=", 
  RowBox[{
   RowBox[{"Series", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", ",", 
           RowBox[{"t", "+", "dt"}]}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "/", "dt"}], " ", "+", 
      RowBox[{"v", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "-", 
          RowBox[{"f", "[", 
           RowBox[{
            RowBox[{"x", "-", "h"}], ",", "t"}], "]"}]}], ")"}], "/", 
        "h"}]}]}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"dt", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
   "Normal"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["f", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "t"}], "]"}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "dt", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{"v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "h", " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"truncerr", "=", 
  RowBox[{"diffscheme", " ", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}], "+", 
     RowBox[{"v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "dt", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "h", " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"truncerr", "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "t"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"v", "^", "2"}], 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "v", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "h"}], "+", 
    RowBox[{"dt", " ", "v"}]}], ")"}], " ", 
  RowBox[{
   SuperscriptBox["f", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"2", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "t"}], "]"}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implicit Upwind", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"diffscheme", "=", 
  RowBox[{
   RowBox[{"Series", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x", ",", 
           RowBox[{"t", "+", "dt"}]}], "]"}], "-", 
         RowBox[{"f", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "/", "dt"}], " ", "+", 
      RowBox[{"v", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f", "[", 
           RowBox[{"x", ",", 
            RowBox[{"t", "+", "dt"}]}], "]"}], "-", 
          RowBox[{"f", "[", 
           RowBox[{
            RowBox[{"x", "-", "h"}], ",", 
            RowBox[{"t", "+", "dt"}]}], "]"}]}], ")"}], "/", "h"}]}]}], " ", 
     ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"dt", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
   "Normal"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["f", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "t"}], "]"}], "+", 
  RowBox[{"v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "h", " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{"dt", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "+", 
     RowBox[{"v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", "h", " ", "v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"truncerr", "=", 
  RowBox[{"diffscheme", " ", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}], "+", 
     RowBox[{"v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "h", " ", "v", " ", 
   RowBox[{
    SuperscriptBox["f", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "t"}], "]"}]}], "+", 
  RowBox[{"dt", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "+", 
     RowBox[{"v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", "h", " ", "v", " ", 
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"truncerr", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"v", "^", "2"}], 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "t"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "v"}], " ", 
       RowBox[{
        SuperscriptBox["f", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "v", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"h", "+", 
       RowBox[{"dt", " ", "v"}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"dt", " ", "h", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{971, 740},
WindowMargins->{{Automatic, 408}, {101, Automatic}},
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (December 10, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 47, 0, 90, "Title"],
Cell[630, 24, 228, 7, 31, "Input"],
Cell[CellGroupData[{
Cell[883, 35, 23, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[931, 39, 614, 21, 31, "Input"],
Cell[1548, 62, 908, 26, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2493, 93, 276, 9, 31, "Input"],
Cell[2772, 104, 424, 13, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3233, 122, 224, 7, 31, "Input"],
Cell[3460, 131, 525, 16, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4022, 152, 100, 2, 31, "Input"],
Cell[4125, 156, 151, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4313, 165, 92, 2, 31, "Input"],
Cell[4408, 169, 198, 7, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4655, 182, 22, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[4702, 186, 705, 24, 31, "Input"],
Cell[5410, 212, 851, 26, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6298, 243, 276, 9, 31, "Input"],
Cell[6577, 254, 710, 21, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7324, 280, 224, 7, 31, "Input"],
Cell[7551, 289, 518, 15, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8106, 309, 100, 2, 31, "Input"],
Cell[8209, 313, 205, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8451, 324, 119, 4, 31, "Input"],
Cell[8573, 330, 261, 9, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8883, 345, 34, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[8942, 349, 564, 19, 31, "Input"],
Cell[9509, 370, 782, 22, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10328, 397, 276, 9, 31, "Input"],
Cell[10607, 408, 288, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10932, 421, 224, 7, 31, "Input"],
Cell[11159, 430, 256, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11452, 441, 311, 7, 31, "Input"],
Cell[11766, 450, 983, 26, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12786, 481, 124, 2, 31, "Input"],
Cell[12913, 485, 1816, 52, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14766, 542, 126, 3, 31, "Input"],
Cell[14895, 547, 294, 8, 31, "Output"]
}, Open  ]],
Cell[15204, 558, 117, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[15346, 564, 94, 2, 31, "Input"],
Cell[15443, 568, 419, 14, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15899, 587, 716, 20, 34, "Input"],
Cell[16618, 609, 467, 13, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17122, 627, 662, 21, 48, "Input"],
Cell[17787, 650, 650, 19, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18474, 674, 507, 15, 31, "Input"],
Cell[18984, 691, 943, 29, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19964, 725, 246, 7, 31, "Input"],
Cell[20213, 734, 300, 7, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20550, 746, 162, 3, 31, "Input"],
Cell[20715, 751, 419, 14, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21171, 770, 160, 3, 31, "Input"],
Cell[21334, 775, 330, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21701, 789, 196, 6, 31, "Input"],
Cell[21900, 797, 352, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22289, 813, 152, 3, 31, "Input"],
Cell[22444, 818, 468, 16, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22961, 840, 31, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[23017, 844, 845, 29, 31, "Input"],
Cell[23865, 875, 1274, 39, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25176, 919, 276, 9, 31, "Input"],
Cell[25455, 930, 918, 26, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26410, 961, 329, 9, 31, "Input"],
Cell[26742, 972, 843, 24, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27622, 1001, 194, 4, 31, "Input"],
Cell[27819, 1007, 390, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28246, 1023, 187, 4, 31, "Input"],
Cell[28436, 1029, 524, 17, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28997, 1051, 721, 21, 36, "Input"],
Cell[29721, 1074, 516, 15, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30274, 1094, 468, 14, 34, "Input"],
Cell[30745, 1110, 425, 13, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31207, 1128, 211, 5, 31, "Input"],
Cell[31421, 1135, 786, 24, 55, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32268, 1166, 28, 0, 90, "Title"],
Cell[CellGroupData[{
Cell[32321, 1170, 34, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[32380, 1174, 856, 27, 31, "Input"],
Cell[33239, 1203, 1579, 60, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34855, 1268, 602, 21, 34, "Input"],
Cell[35460, 1291, 1150, 43, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36647, 1339, 586, 21, 34, "Input"],
Cell[37236, 1362, 1123, 39, 55, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38408, 1407, 23, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[38456, 1411, 943, 30, 52, "Input"],
Cell[39402, 1443, 1019, 39, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40458, 1487, 602, 21, 34, "Input"],
Cell[41063, 1510, 590, 22, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41690, 1537, 712, 25, 34, "Input"],
Cell[42405, 1564, 624, 22, 55, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[43078, 1592, 22, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[43125, 1596, 1195, 38, 72, "Input"],
Cell[44323, 1636, 1330, 51, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45690, 1692, 602, 21, 34, "Input"],
Cell[46295, 1715, 901, 34, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47233, 1754, 174, 5, 31, "Input"],
Cell[47410, 1761, 1139, 38, 81, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48586, 1804, 712, 25, 34, "Input"],
Cell[49301, 1831, 776, 27, 58, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50126, 1864, 34, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[50185, 1868, 865, 28, 31, "Input"],
Cell[51053, 1898, 994, 38, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52084, 1941, 602, 21, 34, "Input"],
Cell[52689, 1964, 565, 21, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53291, 1990, 586, 21, 34, "Input"],
Cell[53880, 2013, 373, 14, 55, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54302, 2033, 34, 0, 63, "Section"],
Cell[CellGroupData[{
Cell[54361, 2037, 930, 30, 52, "Input"],
Cell[55294, 2069, 1635, 60, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56966, 2134, 602, 21, 34, "Input"],
Cell[57571, 2157, 1226, 44, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58834, 2206, 1210, 42, 34, "Input"],
Cell[60047, 2250, 716, 26, 55, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

